function [alplussim,betasim,gammasim,alphasim,betapostm,betapostchol,archpostm,archpostchol,garchpostm,garchpostchol,accar,accga,accab,irejsa,irejsg] = ... 
    mcmcgarch(y,lags,qu,pe,alpha,gamma,betac,pralm,pralinf,prgam,prgainf,prbem,prbeinf,post,it0,it,rth);
% function [betasim,gammasim,alphasim,htlow,htup,htmean,betapostm,betapostchol,archpostm,archpostchol,accag,accagb,irejsum,loglik] = ... 
%     mcmcgarch(y,lags,qu,pe,alpha,gamma,beta,pralm,pralinf,prgam,prgainf,prbem,prbeinf,post,it0,it,rth);
% 
% function call: 
%
% INPUT:
% y     time series, (nx1) vector
% lags  number of lagged dependent variables
% qu    number of ARCH terms
% pe    number of GARCH terms
% alpha  initial values (mx1), m=qu+pe
% gamma  initial values for changing variances (1x1)
% betac   initial value for constant and lagged dep. variables
% pralm  prior mean for ARCH&GARCH terms
% pralinf prior info for ARCH&GARCH terms
% prgam  prior mean for constant in GARCH equation
% prgainf prior info ....
% prbem  prior mean for betac
% prbeinf prior info....
% post  hyperparameters of posterior are (0) not stored, (1) stored
% it    number of iterations
% it0   number of iterations discarded
% rth   store every itr-th draw
%
% OUTPUT:
% simulated values:
% [betasim,gammasim,alphasim,htlow,htup,htmean,betapostm,betapostchol,archpostm,archpostchol,accag,accagb,irejsum,loglik]
%  betac,gamma,alpha,conditional variance,hyperparameters of posterior for betac, GARCH equation,
%  acceptance rate for alpha, for betac, rejection rate for alpha,log likelihood
% 
% Author: Sylvia Kaufmann, July 2005
%         (based on Nakatsuma (2000), Journal of Econometrics)
%  permutation
% perm=1; %identifiability constraint
%perm=2; %random permutation sampling

MMC=1000; % number of posterior hyperparameters that are stored
itr=sum(~mod([it0+1:it],rth)); %number of retained draws
sit=1;

rand('state',0);
randn('state',0);

n=size(y,1);
index=[];for i=1:lags;index=[index;lags-i+1:n-i];end;index=index';
Z=[ones(n-lags,1) y(index)];
y=y(lags+1:end);

nst=1;
pini=ones(nst,1)/nst;

m=size(alpha,1);
n = size(y,1)+1;

% htlow=zeros(ceil((it-it0)*0.025),n-m-1);
% htup=zeros(ceil((it-it0)*0.025),n-m-1);
% htmean=zeros(1,n-m-1);

alphasim=zeros(m,itr);
alplussim=zeros(pe,itr);
gammasim=zeros(1,itr);
betasim=zeros(lags+1,itr);

betapostm=zeros(lags+1,post*MMC+(1-post));
betapostchol=zeros(lags+1,lags+1,post*MMC+(1-post));
archpostm=zeros(qu+1,post*MMC+(1-post));
archpostchol=zeros(qu+1,qu+1,post*MMC+(1-post));
garchpostm=zeros(pe,post*MMC+(1-post));
garchpostchol=zeros(pe,pe,post*MMC+(1-post));
if post
    pit=[simuni(it-it0,MMC)+it0];
else 
    pit=[];
end

irejsa=0;
irejsg=0;
accar=0;accga=0;
accab=0;
accb=0;acca=0;accg=0;
ireja=0;
irejg=0;
loglik=zeros(itr,1);

for j = 1:it
    
%     if any([1:1000:it]==j)
        j
%     end
    %     [fv sp] = filtvertbetalev(y,Z,eta,pini,alpha,gamma,xi,betac);
    %     if j > 1 loglik(j-1)=sp;
    %     end;
    %     sst = simstate(fv,eta);
    %     
    %     [eta cnt] = simtrans(nst,sst(1+m:end),e0,1.);
    
    %simulate betac
    [betac accb mubeta prvbeta crwbeta]=simbetaparinfo(y,Z,alpha,gamma,betac,prbem,prbeinf,qu);
    
    %simulate ARCH and constant
    [alpha gamma ireja acca muarch prvarch crwarch]=simarchparinfo(y-Z*betac,alpha,gamma,pralm,pralinf,prgam,prgainf,qu);
    
    %simulate GARCH
    [alplus alpha gamma irejg accg mugarch prvgarch crwgarch]=simgarchparinfo(y-Z*betac,alpha,gamma,pralm,pralinf,qu);
    
    
    if j>it0
        accar=accar+acca;accga=accga+accg;irejsa=irejsa+ireja;
        irejsg=irejsg+irejg;
        accab=accab+accb;
        
        if ~mod(j,rth)
            alphasim(:,sit)=alpha;
            alplussim(:,sit)=alplus;
            gammasim(:,sit)=gamma;
            betasim(:,sit)=betac;
            sit=sit+1;
            
        end
        if any(j==pit)
            jm=find(j==pit);
            betapostm(:,jm)=mubeta;
            betapostchol(:,:,jm)=crwbeta;
            archpostm(:,jm)=muarch;
            archpostchol(:,:,jm)=crwarch;
            garchpostm(:,jm)=mugarch;
            garchpostchol(:,:,jm)=crwgarch;
        end
    end   
    
    
    
    
end

% [fv loglik(it)] = filtvertbetalev(y,Z,eta,pini,alpha,gamma,xi,betac);
accar=accar/(it-it0);accga=accga/(it-it0);irejsa=irejsa/(it-it0);
irejsg=irejsg/(it-it0);
accab=accab/(it-it0);

% htmean=htmean/(it-it0);
