function [hthat,sq_hthat_mean,sq_sum_hthat] = garchforecast_bayes(y,Z,qu,alpha,gamma,beta,steps);

% function call: [ghthat,sq_ghthat,sq_sum_ghthat] = garchforecast_bayes(y,Z,qu,alpha,gamma,beta,for_steps);
%
% INPUT:
% y     time series, (nx1) vector
% Z     time series, (nx number of variables)
% qu    number of ARCH terms 
% alpha  fixed values  (mx1), qu ARCH terms, size(galpha,1)-qu= pe GARCH terms
% gamma  fixed value  constant in the cond.variance equation 
% beta   fixed value for constant and lagged dep. variables
% steps  forcasting steps
%
% OUTPUT:
% simulated values:
% hthat, steps-step ahead predicted ht (volatility squared)
% sq_hthat_mean, mean volatility over steps-step forecasting period
% sq_sum_hthat, square root of mean predicted ht (volatility squared) over steps-step
% 
% Authors: Sylvia Kaufmann

pe=size(alpha,1)-qu;
gl=max(qu,pe);
ut=(y-Z*beta);
n=size(ut,1);
index=[];for i=1:qu;index=[index;qu-i+1:n-i];end;index=index';
U=ut(index).^2;

n=size(ut,1)-qu;
hthat=zeros(n+pe,1);
hthat(1:pe)=gamma./(1-sum(alpha))*ones(pe,1);
% vola_garch(1)=sqrt(parms(1)+parms(2)*utsq(1)+parms(3)*start_val);
for j=1:n;
    htlag=[U(j,:) hthat(j-1+pe:-1:j)];
    hthat(j+pe)=gamma+htlag*alpha;
end

pindex=[];for i=1:pe;pindex=[pindex;pe-i+2:n+pe-i+1];end;pindex=pindex';
Hlag=hthat(pindex);

hthat=hthat(pe+1:end);
n=size(hthat,1);
hthat_1step=hthat;
Ulag=U;
sq_hthat_mean=sqrt(hthat);
sum_hthat=hthat;

for j=1:steps-1
    Uthat=(sqrt(hthat).*randn(n,1)).^2;
    Ulag=[Uthat Ulag(:,1:end-1)];
    Hlag=[hthat Hlag(:,1:end-1)];
    hthat=gamma+[Ulag Hlag]*alpha;
    sq_hthat_mean=sq_hthat_mean+sqrt(hthat);
    sum_hthat=sum_hthat+hthat;
end

sq_hthat_mean=sq_hthat_mean./steps;
sq_sum_hthat=sqrt(sum_hthat./steps);
