function [pv,time,mDk,mDk_rep] = icss_bayes(file,sw,L,c_end,freq);

%input
% file  file name with MCMC draws or implied volatility
% sw    flag to indicate which model: (1) SWARCH (2) GARCH (3) implied volatility
% L     number of draws to evaluate posterior predictive statistic
% c_end end date of series
% freq  (12) monthly (4) quaterly (260) daily
%
%output
% pv    p-value Pr(T(y_rep,theta)>=T(y,theta)|y)
% time  break in variance date, [rn cn], rn indicates in which row (which observation),
%                                        cn indicates in which column (how many times) abs(Dk)>abs(Dk_rep)
time=[];
load(file);
cal=load(['date_' int2str(c_end) '.txt']);
if sw==1
    %     abschneiden;
    permutieren;
    MMC=size(etasim,3);
    if L<MMC;
        % zufllige auswahl der MCMC simulationen
        ind = simuni(MMC,L);
        %         etamc=etasima(:,:,ind);
        alphasim=alphasim(:,ind);
        gammasim=gammasim(:,ind);
        betasim=betasim(:,ind);
        xisim=xisim(:,ind);
        sstsim=sstsim(:,:,ind);
    end
    n=size(y,1);
    index=[];for i=1:lags;index=[index;lags-i+1:n-i];end;index=index';
    Z=[ones(n-lags,1) y(index)];
    y=y(lags+1:end);
    nst=size(gammasim,1);
    qu=size(alphasim,1);
    clear *sima* loglik
elseif sw==2
    MMC=size(alphasim,2);
    if L<MMC;
        % zufllige auswahl der MCMC simulationen
        ind = simuni(MMC,L);
        alphasim=alphasim(:,ind);
        gammasim=gammasim(:,ind);
        betasim=betasim(:,ind);
    end
    n=size(y,1);
    index=[];for i=1:lags;index=[index;lags-i+1:n-i];end;index=index';
    Z=[ones(n-lags,1) y(index)];
    y=y(lags+1:end);
    pe=size(alphasim,1)-qu;
    clear  *post*
elseif sw==3
    vol=dax_99(2:end,2)/sqrt(252);
    y=100*(log(dax_99(2:end,1))-log(dax_99(1:end-1,1)));
    qu=0;
end

cnt=0;

T=size(y,1)-qu;
% L=10000;
cal=cal(end-T+1:end);
cal_run = 1:T;
c = fix(cal(end)/1e4);
cal_pl = [sort(c-cal_run/freq)]';
Ck_rep=zeros(T,L);
Dk_rep=zeros(T,L);
mDk_rep=zeros(1,L);
Ck=zeros(T,L);
Dk=zeros(T,L);
mDk=zeros(1,L);


erst=randn(T,L);
k=[1:T]';

if sw==1

    for j=1:L
        Ck_rep(:,j)=cumsum(erst(:,j).^2,1);
        Dk_rep(:,j)=Ck_rep(:,j)./Ck_rep(T,j)- k./T;
        mDk_rep(1,j)= max(sqrt(T/2)*abs(Dk_rep(:,j)),[],1);

        u=y-Z*betasim(:,j);
        index=[];for i=1:qu;index=[index;qu-i+1:T+qu-i];end;index=index';
        U=u(index).^2;
        dt=(u(qu:end-1)<=0.0).*u(qu:end-1).^2;

        ht=sstsim(:,end-T+1:end,j)'*gammasim(:,j)+U*alphasim(:,j)+dt*xisim(:,j);
        ust=u(end-T+1:end)./sqrt(ht);

        Ck(:,j)=cumsum(ust.^2,1);
        Dk(:,j)=Ck(:,j)./Ck(T,j)- k./T;
        mDk(1,j)= max(sqrt(T/2)*abs(Dk(:,j)),[],1);
    end

elseif sw==2
    for j=1:L
        Ck_rep(:,j)=cumsum(erst(:,j).^2,1);
        Dk_rep(:,j)=Ck_rep(:,j)./Ck_rep(T,j)- k./T;
        mDk_rep(1,j)= max(sqrt(T/2)*abs(Dk_rep(:,j)),[],1);

        u=y-Z*betasim(:,j);
        index=[];for i=1:qu;index=[index;qu-i+1:T+qu-i];end;index=index';
        U=u(index).^2;

        hthat=zeros(T+pe,1);
        hthat(1:pe)=gammasim(:,j)./(1-sum(alphasim(:,j)))*ones(pe,1);
        % vola_garch(1)=sqrt(parms(1)+parms(2)*utsq(1)+parms(3)*start_val);
        for t=1:T;
            htlag=[U(t,:) hthat(t-1+pe:-1:t)];
            hthat(t+pe)=gammasim(:,j)+htlag*alphasim(:,j);
        end

        ust=u(end-T+1:end)./sqrt(hthat(end-T+1:end));

        Ck(:,j)=cumsum(ust.^2,1);
        Dk(:,j)=Ck(:,j)./Ck(T,j)- k./T;
        mDk(1,j)= max(sqrt(T/2)*abs(Dk(:,j)),[],1);
    end

elseif sw==3

    ust=y./vol;

    Ck=kron(ones(1,L),cumsum(ust.^2,1));
    Dk=Ck./Ck(T*ones(1,T),:)- kron(ones(1,L),k)./T;
    mDk= max(sqrt(T/2)*abs(Dk),[],1);

    for j=1:L
        Ck_rep(:,j)=cumsum(erst(:,j).^2,1);
        Dk_rep(:,j)=Ck_rep(:,j)./Ck_rep(T,j)- k./T;
        mDk_rep(1,j)= max(sqrt(T/2)*abs(Dk_rep(:,j)),[],1);
    end

end

pv = sum(mDk_rep>=mDk)/L;
cn_ser=find(mDk_rep>=mDk);

if (pv<=0.05)+(pv>=0.95)
    [r,c]=find(abs(Dk(:,cn_ser))==kron(ones(T,1),max(abs(Dk(:,cn_ser)),[],1)));
    time=cal(r);
end
    
